coinor.blimpy.Queues

Package coinor :: Package blimpy :: Module Queues |
[hide private]
[frames] | no frames]

# Module Queues

source code

This module implements a Queue class, a simple list-based queue data structure and a PriorityQueue class, which is a heap-based priority queue data structure.

Version: 1.1.0

Author: Aykut Bulut, Ted Ralphs (ayb211@lehigh.edu,ted@lehigh.edu)

License: BSD

Classes | [hide private]
| Queue A queue data structure built on top of a linked list...
| PriorityQueue A priority queue based on a heap.

Variables | [hide private]
| __maintainer__ = ``'``Aykut Bulut``'``
| __email__ = ``'``ayb211@lehigh.edu``'``
| __url__ = `None`
| __title__ = ``'``Queue data structure``'``
| __package__ = ``'``coinor.blimpy``'``